@@ -142,9 +142,6 @@ class Bot:
         self.start()
 
 
-    def nothing(msg):
-        return
-
     def start(self, function = None, advanced = False):
         if not (self.advanced or advanced):
             try:
@@ -375,7 +372,7 @@ class Bot:
     def initiate_pm(self, id, bot = None):
         copy = Bot(nick = self.nick, room = "pmtest")
         copy.connect()
-        copy.login(email="anonymous@magrittescow.com", password = "correcthorsebatterystaple")
+        copy.login()
         copy.conn.close()
         del copy.conn
         copy.connect()
